pub struct NativeScript(/* private fields */);Implementations
Sourceimpl NativeScript
impl NativeScript
pub fn from_bytes(bytes: Vec<u8>) -> Result<NativeScript, DeserializeError>
Sourceimpl NativeScript
impl NativeScript
pub fn from_hex(hex_str: &str) -> Result<NativeScript, DeserializeError>
Sourceimpl NativeScript
impl NativeScript
Sourceimpl NativeScript
impl NativeScript
pub fn hash(&self) -> ScriptHash
pub fn new_script_pubkey(script_pubkey: &ScriptPubkey) -> NativeScript
pub fn new_script_all(script_all: &ScriptAll) -> NativeScript
pub fn new_script_any(script_any: &ScriptAny) -> NativeScript
pub fn new_script_n_of_k(script_n_of_k: &ScriptNOfK) -> NativeScript
pub fn new_timelock_start(timelock_start: &TimelockStart) -> NativeScript
pub fn new_timelock_expiry(timelock_expiry: &TimelockExpiry) -> NativeScript
pub fn kind(&self) -> NativeScriptKind
pub fn as_script_pubkey(&self) -> Option<ScriptPubkey>
pub fn as_script_all(&self) -> Option<ScriptAll>
pub fn as_script_any(&self) -> Option<ScriptAny>
pub fn as_script_n_of_k(&self) -> Option<ScriptNOfK>
pub fn as_timelock_start(&self) -> Option<TimelockStart>
pub fn as_timelock_expiry(&self) -> Option<TimelockExpiry>
Sourcepub fn get_required_signers(&self) -> Ed25519KeyHashes
pub fn get_required_signers(&self) -> Ed25519KeyHashes
Returns a set of Ed25519KeyHashes contained within this script recursively on any depth level. The order of the keys in the result is not determined in any way.