Function resolve_epoch_no
pub fn resolve_epoch_no(
network: &Network,
milliseconds: Option<u64>,
) -> Option<u64>
Resolve the epoch number for a network at a given time.
Arguments
network - The Cardano network
milliseconds - Optional POSIX time in milliseconds (defaults to current time)
Returns
The epoch number, or None if the network is Custom